@@ -1,41 +1,22 @@
 from pykin.kinematics.transform import Transform
 
 
-class Box:
-    def __init__(self, size):
-        self.size = size
-
-    def __repr__(self):
-        return f"""Box(size={self.size})"""
-
-
-class Cylinder:
-    def __init__(self, radius, length):
-        self.radius = radius
-        self.length = length
-
-    def __repr__(self):
-        return f"""Cylinder(radius={self.radius} 
-                            length={self.length})"""
-
-
-class Sphere:
-    def __init__(self, radius):
-        self.radius = radius
-
-    def __repr__(self):
-        return f"""Sphere(radius={self.radius}"""
-
-
-class Mesh:
-    def __init__(self):
-        pass
-
-
 class Visual:
-    TYPES = ['box', 'cylinder', 'sphere', 'capsule', 'mesh']
-    def __init__(self, offset=Transform(), 
-                 geom_type=None, geom_param=None):
+    """
+    class of Visual
+
+    Args:
+        offset (Transform): visual offset
+        geom_type (str): visual type (box, cylinder, spehre, mesh)
+        geom_param (dict): visual parameters 
+    """
+    TYPES = ['box', 'cylinder', 'sphere', 'mesh']
+    def __init__(
+        self, 
+        offset=Transform(), 
+        geom_type=None, 
+        geom_param=None
+    ):
         self.offset = offset
         self.gtype = geom_type
         self.gparam = geom_param
@@ -55,9 +36,21 @@ class Visual:
 
 
 class Collision:
+    """
+    class of Collision
+
+    Args:
+        offset (Transform): collision offset
+        geom_type (str): collision type (box, cylinder, spehre, mesh)
+        geom_param (dict): collision parameters 
+    """
     TYPES = ['box', 'cylinder', 'sphere', 'mesh']
-    def __init__(self, offset=Transform(), 
-                 geom_type=None, geom_param=None):
+    def __init__(
+        self, 
+        offset=Transform(), 
+        geom_type=None, 
+        geom_param=None
+    ):
         self.offset = offset
         self.gtype = geom_type
         self.gparam = geom_param
